@@ -1,6 +1,6 @@
 package App::DDNS::Namecheap;
 {
-  $App::DDNS::Namecheap::VERSION = '0.013';
+  $App::DDNS::Namecheap::VERSION = '0.014';
 }
 
 use Moose;
@@ -11,15 +11,18 @@ use Mozilla::CA;
 has domain => ( is => 'ro', isa => 'Str', required => 1 );
 has password => ( is => 'ro', isa => 'Str', required => 1 );
 has hosts => ( is => 'ro', isa => 'ArrayRef', required => 1 );
+has ip => ( is => 'ro', isa => 'Str', required => 0 );
 
 sub update {
   my $self = shift;
   foreach ( @{ $self->{hosts} } ) {
     my $url = "https://dynamicdns.park-your-domain.com/update?domain=$self->{domain}&password=$self->{password}&host=$_";
+    $url .= "&ip=$self->{ip}" if $self->{ip};
     if ( my $return = get($url) ) {
       unless ( $return =~ /<errcount>0<\/errcount>/is ) {
 	$return = ( $return =~ /<responsestring>(.*)<\/responsestring>/is ? $1 : "unknown error" );
         print "failure submitting host \"$_\.$self->{domain}\": $return\n";
+	return;
       }
     }
   }
@@ -37,7 +40,7 @@ App::DDNS::Namecheap - Dynamic DNS update utility for Namecheap registered domai
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -45,14 +48,15 @@ version 0.013
                       domain   => 'mysite.org',
          	      password => 'abcdefghijklmnopqrstuvwxyz012345',
 		      hosts    => [ "@", "www", "*" ],
+                      ip       => '127.0.0.1',    #optional -- defaults to external ip
     );
 
     $domain->update();
 
 =head1 DESCRIPTION
 
-This module provides a method for setting the address records of your Namecheap registered 
-domains to your external IP address. 
+This module provides a method for setting the address records of your Namecheap hosted 
+domains. 
 
 =head1 METHODS
 
@@ -60,7 +64,8 @@ domains to your external IP address.
 
 =item B<update>
 
-Updates Namecheap A records using the three attributes listed above.
+Updates Namecheap A records using the attributes listed above. The optional ip attribute 
+can be set statically; otherwise the ip where the script is running will be used.
 
 =back
 
